@@ -17,16 +17,19 @@ import json
 import os
 
 RQDATAC_DEFAULT_ADDRESS = "rqdatad-pro.ricequant.com:16011"
-PERMISSIONS_INFO_URL = "http://www.ricequant.com/api/rqlicense/get_permissions_readable_info"
+PERMISSIONS_INFO_URL = "https://www.ricequant.com/api/rqlicense/get_permissions_readable_info"
 EXTRA_INDEX_URL = "https://rquser:Ricequant8@pypi2.ricequant.com/simple/"
 BASH_FILE = [".bash_profile", ".bashrc", ".bash_profile", ".zshrc"]
 TAG_MAP = ["stock", "futures", "fund", "index", "option", "convertible", ]
 DEFAULT_BUNDLE_PATH = os.path.join(os.path.expanduser('~'), ".rqalpha-plus")
 
-VERSION_MAP = {}
+PRODUCTS = ["rqalpha_plus", "rqdatac", "rqfactor", "rqoptimizer"]
+CONCERNED_PACKAGES = [
+    "rqsdk", "rqdatac", "rqdatac_fund",
+    "rqfactor", "rqoptimizer", "rqrisk",
+    "rqalpha_plus", "rqalpha", "rqalpha_mod_spot", "rqalpha_mod_option", "rqalpha_mod_optimizer2",
+    "rqalpha_mod_convertible", "rqalpha_mod_ricequant_data", "rqalpha_mod_rqfactor", "rqalpha_mod_fund",
+    "rqalpha_mod_spot",
+    "pandas", "numpy", "h5py"
+]
 
-version_map_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "version_map.json"))
-if os.path.exists(version_map_path):
-    with open(version_map_path, 'r', encoding="utf8") as f:
-        VERSION_MAP = json.loads(f.read())
-del version_map_path
